
/*
-------------------------------------------------------------------------------
Name:		TB_DeleteHiddenAndEmptyLayers.js

Description:	This script iterates over the selected panels and deletes all empty or hidden layers.

Usage:		

Author:		Corey Barnes and Karl Olson, slightly modified from the original TB_DeleteHiddenLayers.js by Lori Sponagle

Created:	v01 2018/09/22
            
Copyright:   (c) Toon Boom Animation 2018

Version: 1.0.2

Social Media Info:
Corey on Twitter - http://twitter.com/myanimewaifu
Karl on Twitter - http://twitter.com/karlrolson

Contact Email: livingfruitvirus@gmail.com
 
-------------------------------------------------------------------------------
*/

function TB_DeleteHiddenAndEmptyLayers()
{
  var selection = new SelectionManager;
  var selIds = selection.getPanelSelection();
  if ( selIds.length <= 0 ) return;
  
  var layM = new LayerManager;
  var sM = new StoryboardManager;

  var delLayers = new Array(0);

  // Open Undo scope
  scene.beginUndoRedoAccum("Delete Hidden and Empty Layers");

  for ( var i = 0; i < selIds.length; ++ i )
  {
    var panelId = selIds[i];
       
      for ( var j =  layM.numberOfLayers( panelId ) - 1; j >= 0; --j )
      {
        var lName = layM.layerName( panelId, j);
        var layerId = {name: lName,panelId: panelId};
        
         if ( layM.isEmpty( layerId ) == true || layM.layerVisibility( panelId, j ) == false)
         {
              delLayers += (" Scene: " + sM.nameOfScene( sM.sceneIdOfPanel( panelId ) ) 
                        + "    Panel: " + sM.nameOfPanel( panelId ) 
                        + "    Layer: " + layM.layerName( panelId, j ) 
                        + "\n" );
              layM.deleteLayer( panelId, j );
         }
      }
  }
  // Close Undo scope
  scene.endUndoRedoAccum();

  // Prepare report.
  if ( delLayers.length > 0 )
  {
     var finalMessage = "The following layers have been deleted :\n" + delLayers;
     MessageBox.information ( finalMessage );
  }
}
